# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .node_js_session_info import NodeJsSessionInfo


class NodeJsCreateSessionResponse(UniversalBaseModel):
    session_id: str = pydantic.Field()
    """
    Session ID
    """

    created: bool = pydantic.Field()
    """
    Whether the session was newly created
    """

    message: typing.Optional[str] = pydantic.Field(default=None)
    """
    Additional message (e.g., if session already exists)
    """

    session: typing.Optional[NodeJsSessionInfo] = pydantic.Field(default=None)
    """
    Session information (if created)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
