# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .session_status import SessionStatus


class BashSessionInfo(UniversalBaseModel):
    """
    Session info for listing — returned by GET /v1/bash/sessions.
    """

    session_id: str = pydantic.Field()
    """
    Session identifier
    """

    status: SessionStatus = pydantic.Field()
    """
    Session status
    """

    working_dir: str = pydantic.Field()
    """
    Working directory
    """

    created_at: dt.datetime = pydantic.Field()
    """
    Creation timestamp
    """

    last_used_at: dt.datetime = pydantic.Field()
    """
    Last used timestamp
    """

    current_command: typing.Optional[str] = pydantic.Field(default=None)
    """
    Currently executing command
    """

    command_count: typing.Optional[int] = pydantic.Field(default=None)
    """
    Total commands executed
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
