# This file was auto-generated by Fern from our API Definition.

import typing

NavigateRequestWaitUntil = typing.Union[typing.Literal["load", "domcontentloaded", "networkidle", "commit"], typing.Any]
