# This file was auto-generated by Fern from our API Definition.

import typing

Type = typing.Union[
    typing.Literal["selector", "load", "url", "network_idle", "download", "function", "response", "request", "timeout"],
    typing.Any,
]
