# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .tool_spec import ToolSpec


class RuntimeEnv(UniversalBaseModel):
    """
    version, path, etc. (python3, python3.11, python3.12, pip3, pip, uv, jupyter)
    """

    python: typing.List[ToolSpec]
    nodejs: typing.List[ToolSpec]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
